/***********************************************************************************************************************
 *
 * blueBill Core - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it
 * SCM: https://kenai.com/hg/bluebill~core-src
 *
 **********************************************************************************************************************/
package it.tidalwave.semantic.io.impl;

import it.tidalwave.semantic.io.GraphDeserializer;
import it.tidalwave.semantic.io.json.RdfJsonParser;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import javax.annotation.Nonnull;
import org.openrdf.model.Graph;
import org.openrdf.model.impl.GraphImpl;
import org.openrdf.rio.RDFHandlerException;
import org.openrdf.rio.RDFParseException;
import org.openrdf.rio.RDFParser;
import org.openrdf.rio.helpers.StatementCollector;
import org.openrdf.rio.n3.N3ParserFactory;
import org.openrdf.rio.rdfxml.RDFXMLParser;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class DefaultGraphDeserializer implements GraphDeserializer
  {
    @Nonnull
    private String contextUri = "";

    /*******************************************************************************************************************
     *
     * {@inheritDoc}
     *
     ******************************************************************************************************************/
    @Nonnull
    public Graph read (final @Nonnull InputStream is, final @Nonnull String mimeType)
      throws IOException, RDFHandlerException, RDFParseException
      {
        return read(new InputStreamReader(is, "UTF-8"), mimeType);
      }

    /*******************************************************************************************************************
     *
     * {@inheritDoc}
     *
     ******************************************************************************************************************/
    @Nonnull
    public Graph read (final @Nonnull Reader r, final @Nonnull String mimeType)
      throws IOException, RDFHandlerException, RDFParseException
      {
        RDFParser rdfParser = null;

        // We're not using yet the registry since we don't know whether it works with Android
        if (MIME_RDF_JSON.equals(mimeType))
          {
            rdfParser = new RdfJsonParser();
          }
        else if (MIME_RDF_XML.equals(mimeType))
          {
            rdfParser = new RDFXMLParser();
          }
        else if (MIME_N3.equals(mimeType))
          {
            rdfParser = new N3ParserFactory().getParser();
          }
        else
          {
            throw new RDFHandlerException("No parser for MIME type: " + mimeType);
          }

        final StatementCollector statementCollector = new StatementCollector();
        rdfParser.setRDFHandler(statementCollector);
        rdfParser.parse(r, contextUri);

        return new GraphImpl(statementCollector.getStatements());
      }

    /*******************************************************************************************************************
     *
     * {@inheritDoc}
     *
     ******************************************************************************************************************/
    public void setContextUri (final @Nonnull String contextUri)
      {
        this.contextUri = contextUri;
      }
  }
