/***********************************************************************************************************************
 *
 * blueBill Core - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it
 * SCM: https://kenai.com/hg/bluebill~core-src
 *
 **********************************************************************************************************************/
package it.tidalwave.semantic.io.spi;

import javax.annotation.Nonnull;
import org.openide.util.Lookup;
import it.tidalwave.role.Displayable;
import it.tidalwave.semantic.Property;
import it.tidalwave.semantic.Type;
import it.tidalwave.semantic.io.impl.Vocabulary;
import it.tidalwave.util.As;
import it.tidalwave.util.AsException;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class AsStatementMarshaller implements StatementMarshaller
  {
    /*******************************************************************************************************************
     *
     *
     ******************************************************************************************************************/
    @Nonnull
    public void marshal (final @Nonnull As entity, final @Nonnull Context context)
      {
        context.addStatement(entity, Vocabulary.RDF_TYPE, Vocabulary.OWL_THING);
        context.addStatement(entity, Vocabulary.RDF_TYPE, Vocabulary.SKOS_CONCEPT);

        if (entity instanceof Lookup.Provider)
          {
            for (final Type type : ((Lookup.Provider)entity).getLookup().lookupAll(Type.class))
              {
                context.addStatement(entity, Vocabulary.RDF_TYPE, type.getId());
              }

            for (final Property property : ((Lookup.Provider)entity).getLookup().lookupAll(Property.class))
              {
                context.addStatement(entity, property.getId(), property.getValue());
              }
          }

        try
          {
            final Displayable displayable = entity.as(Displayable.class);
            // FIXME: for each language
            context.addStatement(entity, Vocabulary.RDFS_LABEL, displayable.getDisplayName());
          }
        catch (AsException e)
          {
            // never mind, it's not displayable
          }
      }
  }
